==> coin2_2.5.0.orig.tar.gz: Coin-2.5.0/src/misc/all-misc-cpp.cpp <==
/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2007 by Systems in Motion.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Systems in Motion about acquiring
 *  a Coin Professional Edition License.
 *
 *  See http://www.coin3d.org/ for more information.
 *
 *  Systems in Motion, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  http://www.sim.no/  sales@sim.no  coin-support@coin3d.org
 *
\**************************************************************************/

#include "SoBase.cpp"
#include "SoChildList.cpp"
#include "SoDB.cpp"
#include "SoDebug.cpp"
#include "SoFullPath.cpp"
#include "SoGL.cpp"
#include "SoGLBigImage.cpp"
#include "SoGLImage.cpp"
#include "SoGenerate.cpp"
#include "SoGlyph.cpp"
#include "SoInteraction.cpp"
#include "SoLightPath.cpp"
#include "SoLockManager.cpp"
#include "SoNormalGenerator.cpp"
#include "SoNotification.cpp"
#include "SoNotRec.cpp"
#include "SoOffscreenRenderer.cpp"
#include "SoOffscreenGLXData.cpp"
#include "SoOffscreenAGLData.cpp"
#include "SoOffscreenWGLData.cpp"
#include "CoinOffscreenGLCanvas.cpp"
#include "SoPath.cpp"
#include "SoPickedPoint.cpp"
#include "SoPrimitiveVertex.cpp"
#include "SoSceneManager.cpp"
#include "SoState.cpp"
#include "SoTempPath.cpp"
#include "SoType.cpp"
#include "SoContextHandler.cpp"
#include "SoProto.cpp"
#include "SoProtoInstance.cpp"
#include "SoPick.cpp"
#include "SoAudioDevice.cpp"
#include "AudioTools.cpp"
#include "CoinStaticObjectInDLL.cpp"
#include "SoVBO.cpp"
#include "SoVertexArrayIndexer.cpp"
#include "PointerMap.cpp"
//#include "SoShaderGenerator.cpp"

==> coin3_3.0.0.orig.tar.gz: Coin-3.0.0/src/misc/all-misc-cpp.cpp <==
/**************************************************************************\
 *
 *  This file is part of the Coin 3D visualization library.
 *  Copyright (C) 1998-2008 by Kongsberg SIM.  All rights reserved.
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  ("GPL") version 2 as published by the Free Software Foundation.
 *  See the file LICENSE.GPL at the root directory of this source
 *  distribution for additional information about the GNU GPL.
 *
 *  For using Coin with software that can not be combined with the GNU
 *  GPL, and for taking advantage of the additional benefits of our
 *  support services, please contact Kongsberg SIM about acquiring
 *  a Coin Professional Edition License.
 *
 *  See http://www.coin3d.org/ for more information.
 *
 *  Kongsberg SIM, Postboks 1283, Pirsenteret, 7462 Trondheim, NORWAY.
 *  http://www.sim.no/  sales@sim.no  coin-support@coin3d.org
 *
\**************************************************************************/

#include "AudioTools.cpp"
#include "CoinOffscreenGLCanvas.cpp"
#include "CoinResources.cpp"
#include "CoinStaticObjectInDLL.cpp"
#include "SoAudioDevice.cpp"
#include "SoBase.cpp"
#include "SoBaseP.cpp"
#include "SoChildList.cpp"
#include "SoCompactPathList.cpp"
#include "SoContextHandler.cpp"
#include "SoDB.cpp"
#include "SoDBP.cpp"
#include "SoDebug.cpp"
#include "SoEventManager.cpp"
#include "SoFullPath.cpp"
#include "SoGL.cpp"
#include "SoGLBigImage.cpp"
#include "SoGLCubeMapImage.cpp"
#include "SoGLDriverDatabase.cpp"
#include "SoGLImage.cpp"
#include "SoGenerate.cpp"
#include "SoGlyph.cpp"
#include "SoInteraction.cpp"
#include "SoJavaScriptEngine.cpp"
#include "SoLightPath.cpp"
#include "SoLockManager.cpp"
#include "SoNormalGenerator.cpp"
#include "SoNotRec.cpp"
#include "SoNotification.cpp"
#include "SoOffscreenAGLData.cpp"
#include "SoOffscreenGLXData.cpp"
#include "SoOffscreenRenderer.cpp"
#include "SoOffscreenWGLData.cpp"
#include "SoPath.cpp"
#include "SoPick.cpp"
#include "SoPickedPoint.cpp"
#include "SoPrimitiveVertex.cpp"
#include "SoProto.cpp"
#include "SoProtoInstance.cpp"
#include "SoRenderManager.cpp"
#include "SoRenderManagerP.cpp"
#include "SoSceneManager.cpp"
#include "SoSceneManagerP.cpp"
#include "SoShaderGenerator.cpp"
#include "SoState.cpp"
#include "SoTempPath.cpp"
#include "SoType.cpp"
#include "SoVBO.cpp"
#include "SoVertexArrayIndexer.cpp"
